#!/bin/bash

base_image_str=`cat image.conf | grep "base_image"`
base_image=${base_image_str#*=}
new_image_str=`cat image.conf | grep "new_image"`
new_image=${new_image_str#*=}

function log {
  local text;local logtype
  logfile=./log.txt
  logtype=$1
  text=$2
  case $logtype in
    ERROR)
      echo -e "\033[31m`date +'%F %H:%M:%S'` $1  $2 \033[0m" | tee -a $logfile;;
    INFO)
      echo -e "`date +'%F %H:%M:%S'` $1  $2" | tee -a $logfile;;
    WARNING)
      echo -e "\033[33m`date +'%F %H:%M:%S'` $1  $2\033[0m" | tee -a $logfile;;
  esac
}

function ask {
    while true
    do
        read -r -p "$1 [Y/n] " input
        case $input in
            [yY][eE][sS]|[yY])
                echo "Yes"
                return 0
                ;;
            [nN][oO]|[nN])
                echo "Cancel next operations..."
                exit 1
                ;;
            *)
                echo "Invalid input,Please try again..."
                ;;
        esac
    done
}

log INFO "Check file: diff_file.tar.gz..."
origin_md5=`sed -n 1p verify.txt | awk '{print $1}'`
local_md5=`md5sum diff_file.tar.gz | awk '{print $1}'`
if [[ $origin_md5 == $local_md5 ]];then
    log INFO "File: diff_file.tar.gz check successful"
else
    log ERROR "File: diff_file.tar.gz corrupted!"
    exit 1
fi

log INFO "=======base image is :${base_image}====="
log INFO "=======new image is :${new_image}======="
ask "Are you sure the name of base_image and target_image are right?"
if [ ! -n "${base_image}" ];
then
  echo "base image is empty,please config the base image and new image in image.conf"
  exit 1
fi
if [ ! -n "${new_image}" ];
then
    echo "new image is empty,please config the base image and new image in image.conf"
    exit 1

fi

if [ $base_image == $new_image ];
then
   docker tag $base_image ${base_image}-backup
fi

sed -i '1d' Dockerfile
sed -i "1i FROM $base_image"  Dockerfile

docker build -t "$new_image" -f Dockerfile .
if [ $? -ne 0 ];then
   echo -e "\033[31m`date +'%F %H:%M:%S'` ERROR image build failed! `call 0`\033[0m" 
   exit 1
fi
ask "Are you sure to push image:$new_image ?"
docker push "$new_image"
if [ $? -ne 0 ];then
   echo -e "\033[31m`date +'%F %H:%M:%S'` ERROR image push failed! `call 0`\033[0m" 
   exit 1
fi


